Introduction
============

In the following, three different use case are presented where the fib-o-mat package is successfully used to generate
FIB patterns.

To find out more about the scientific background, see the associated publication REF (it is open access and not behind
any paywall |:nerd:| ).

.. toctree::
    :maxdepth: 2
    :glob:
    :hidden:

    Magnetic Patterning of Co/Pt Multilayer Films  <copt_multilayer>
    Mechanical resonators based on suspended single-layer graphene <graphene_trampolines>
    Plasmonic tetramer antennas based on single-crystalline gold flakes <plasmonic_antennas>
